ListReq

Struct ListReq 

pub struct ListReq {
    pub start: NaiveDate,
    pub end: NaiveDate,
    /* private fields */
}
A GET request to be made to the /v2/calendar endpoint.

Fields

start: NaiveDate

The (inclusive) start date of the range for which to retrieve calendar data.

end: NaiveDate

The (exclusive) end date of the range for which to retrieve calendar data.