[][src]Struct apca::ApiInfo

pub struct ApiInfo { /* fields omitted */ }

An object encapsulating the information used for working with the Alpaca API.

Implementations

impl ApiInfo[src]

pub fn from_env() -> Result<Self, Error>[src]

Create an ApiInfo object with information from the environment.

This constructor retrieves API related information from the environment and performs some preliminary validation on it. The following information is used:

  • the Alpaca API base URL is retrieved from the APCA_API_BASE_URL variable
  • the Alpaca account key ID is retrieved from the APCA_API_KEY_ID variable
  • the Alpaca account secret is retrieved from the APCA_API_SECRET_KEY variable