pub struct ListReq {
pub start: NaiveDate,
pub end: NaiveDate,
/* private fields */
}Expand description
A GET request to be made to the /v2/calendar endpoint.
Fields
start: NaiveDateThe (inclusive) start date of the range for which to retrieve calendar data.
end: NaiveDateThe (exclusive) end date of the range for which to retrieve calendar data.